@@ -1,10 +1,9 @@
 class Request():
     """ステートマシンからステートへ与えられる引数のまとまり"""
 
-    def __init__(self, context, edge_path=[], line=None, intermachine=None):
+    def __init__(self, context, intermachine, edge_path=[]):
         self._context = context
         self._edge_path = edge_path
-        self._line = line
         self._intermachine = intermachine
 
     @property
@@ -23,15 +22,6 @@ class Request():
         """
         return self._edge_path
 
-    @property
-    def line(self):
-        """外部から与えられる入力文字列
-
-        Examples
-        --------
-        コマンドライン文字列"""
-        return self._line
-
     @property
     def intermachine(self):
         """ステートマシン間の通信手段"""
